<?php

namespace WPRuby_CAA\Core\Features\Plugins;

use WPRuby_CAA\Core\Helpers\Helper;

class Easy_Digital_Downloads extends Plugin {

	public function name(): string {
		return 'Easy Digital Downloads';
	}

	public function key(): string {
		return 'edd';
	}

	public function is_installed(): bool {
		return class_exists( 'Easy_Digital_Downloads', false );
	}

	public function filter()
	{
		if (isset($items['settings']) && count($items['settings']) > 0) {
			$this->block_tab_access('settings', $items);
			add_filter('edd_settings_tabs', [$this, 'remove_settings_tabs'], 999);
		}

		if (isset($items['tools']) && count($items['tools']) > 0) {
			$this->block_tab_access('tools', $items);
			add_filter('edd_tools_tabs', [$this, 'remove_tools_tabs'], 999);
		}
	}

	private function block_tab_access(string $page, array $items)
	{
		$current_tab     = isset( $_GET['tab']   ) ? sanitize_text_field( $_GET['tab'] ) : null;
		$current_page = ! empty( $_REQUEST['page'] ) ? sanitize_title( $_REQUEST['page'] ) : null;

		if (strtolower($current_page) !== 'edd-' . $page ) return;
		if ($current_tab === null) return;

		if (in_array($current_tab, $items[$page])) {
			Helper::block_access();
		}
	}

	public function remove_settings_tabs($tabs) {
		return $this->remove_tabs('settings', $tabs);
	}

	public function remove_tools_tabs($tabs) {
		return $this->remove_tabs('tools', $tabs);
	}

	private function remove_tabs($type, $tabs)
	{
		if(!isset($this->items_to_block[$type])) return $tabs;

		foreach ($this->items_to_block[$type] as $item) {
			if (isset($tabs[$item])) {
				unset($tabs[$item]);
			}
		}
		return $tabs;
	}



	public function menu(): array {

		return [

			'settings' => [
				'name' => 'Settings',
				'menu' => [
					[
						'title' => 'Payments',
						'slug'  => 'gateways'
					],
					[
						'title' => 'Emails',
						'slug'  => 'emails'
					],
					[
						'title' => 'Marketing',
						'slug'  => 'marketing'
					],
					[
						'title' => 'Taxes',
						'slug'  => 'taxes'
					],
					[
						'title' => 'Policies',
						'slug'  => 'privacy'
					],
					[
						'title' => 'Extensions',
						'slug'  => 'extensions'
					],
					[
						'title' => 'Misc',
						'slug'  => 'misc'
					],
				],
			],
			'tools'  => [
				'name' => 'Tools',
				'menu' => [
					[
						'title' => 'API Keys',
						'slug'  => 'api_keys'
					],
					[
						'title' => 'Beta Versions',
						'slug'  => 'betas'
					],
					[
						'title' => 'Logs',
						'slug'  => 'logs'
					],
					[
						'title' => 'System Info',
						'slug'  => 'system_info'
					],
					[
						'title' => 'Debug Log',
						'slug'  => 'debug_log'
					],
					[
						'title' => 'Import/Export',
						'slug'  => 'import_export'
					],
				],
			],
		];
	}


}
